/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: IMethodMetadata.java 3711 2008-07-23 10:24:14Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.scan.api.metadata;

import org.ow2.util.scan.api.metadata.structures.JMethod;

/**
 * Interface of a method metadata.
 * @param <C> interface of a class metadata
 * @param <M> interface of a method metadata
 * @param <F> interface of a field metadata
 * @author Gael Lalire
 */
public interface IMethodMetadata<
    C extends IClassMetadata<C, M, F>,
    M extends IMethodMetadata<C, M, F>,
    F extends IFieldMetadata<C, M, F>> {

    /**
     * @return JMethod object
     */
    JMethod getJMethod();

    /**
     * Sets the JMethod object (for changing some data).
     * @param jMethod the given JMethod object
     */
    void setJMethod(final JMethod jMethod);

    /**
     * @return parent metadata (class)
     */
    C getClassMetadata();

    /**
     * @param classMetadata parent metadata (class)
     */
    void setClassMetadata(final C classMetadata);

}
