/**
 * EasyBeans
 * Copyright (C) 2006-2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: MethodMetadata.java 3718 2008-07-23 17:37:55Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.scan.api.metadata;

import org.ow2.util.scan.api.metadata.structures.JMethod;

/**
 * This class represents the annotation metadata of a method.
 * @author Florent Benoit
 * @param <C> type of class metadata
 * @param <M> type of method metadata
 * @param <F> type of field metadata
 */
public abstract class MethodMetadata<
    C extends IClassMetadata<C, M, F>,
    M extends IMethodMetadata<C, M, F>,
    F extends IFieldMetadata<C, M, F>>
        extends CommonMetadata implements IMethodMetadata<C, M, F> {

    /**
     * Logger.
     */
    //private static Log logger = LogFactory.getLog(MethodAnnotationMetadata.class);

    /**
     * Method on which we got metadata.
     */
    private JMethod jMethod = null;

    /**
     * Parent metadata.
     */
    private C classMetadata = null;

    /**
     * Constructor.
     * @param jMethod the method on which we will set/add metadata
     * @param classMetadata the parent metadata.
     */
    public MethodMetadata(final JMethod jMethod, final C classMetadata) {
        this.jMethod = jMethod;
        this.classMetadata = classMetadata;
    }

    /**
     * @return JMethod object
     */
    public final JMethod getJMethod() {
        return this.jMethod;
    }

    /**
     * Sets the JMethod object (for changing some data).
     * @param jMethod the given JMethod object
     */
    public final void setJMethod(final JMethod jMethod) {
        this.jMethod = jMethod;
    }

    /**
     * @return parent metadata (class)
     */
    public final C getClassMetadata() {
        return classMetadata;
    }

    /**
     * @param classMetadata parent metadata (class)
     */
    public final void setClassMetadata(final C classMetadata) {
        this.classMetadata = classMetadata;
    }

}
